.. pythonbible documentation master file, created by
   sphinx-quickstart on Mon Mar  7 11:35:29 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

pythonbible Documentation
=========================

**pythonbible** is a Python library serving several purposes related to Biblical Scripture referencs:

* finding all Scripture references contained within text
* converting Scripture references to a list of unique verse ids, and vice versa
* retrieving Scripture text by reference or verse ids
* formatting Scripture references for display/print
* formatting Scripture text for display/print

.. note::

   This project is under active development.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   basic_usage
   book_abbreviations
   advanced_usage
   technical_reference
